@@ -139,6 +139,8 @@ class MiniGateway(BaseGateway):
     vn.py用于对接CTP Mini柜台的交易接口。
     """
 
+    default_name: str = "MINI"
+
     default_setting: Dict[str, str] = {
         "用户名": "",
         "密码": "",
@@ -151,7 +153,7 @@ class MiniGateway(BaseGateway):
 
     exchanges: List[str] = list(EXCHANGE_MINI2VT.values())
 
-    def __init__(self, event_engine: EventEngine, gateway_name: str = "MINI") -> None:
+    def __init__(self, event_engine: EventEngine, gateway_name: str) -> None:
         """构造函数"""
         super().__init__(event_engine, gateway_name)
 
